==> angelssmelting_0.3.5.zip: angelssmelting_0.3.5/prototypes/items/angels-chrome.lua <==
data:extend(
{
  {
    type = "item",
    name = "chrome-ore",
    icon = "__angelssmelting__/graphics/icons/ore-chrome.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "processed-chrome",
    icon = "__angelssmelting__/graphics/icons/processed-chrome.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-chrome",
    icon = "__angelssmelting__/graphics/icons/pellet-chrome.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-chromate",
    icon = "__angelssmelting__/graphics/icons/solid-chromate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-dichromate",
    icon = "__angelssmelting__/graphics/icons/solid-dichromate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-chrome-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-chrome-oxide.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "ingot-chrome",
    icon = "__angelssmelting__/graphics/icons/ingot-chrome.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "g",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-molten-chrome",
    icon = "__angelssmelting__/graphics/icons/molten-chrome.png",
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
	auto_barrel = false
  },
  {
    type = "item",
    name = "angels-plate-chrome",
    icon = "__angelssmelting__/graphics/icons/plate-chrome.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome-casting",
    order = "h",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-chrome",
    icon = "__angelssmelting__/graphics/icons/powder-chrome.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome-casting",
    order = "i",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-roll-chrome",
    icon = "__angelssmelting__/graphics/icons/roll-chrome.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome-casting",
    order = "j",
    stack_size = 200
  },
}
)

==> angelssmelting_0.4.3.zip: angelssmelting_0.4.3/prototypes/items/angels-chrome.lua <==
data:extend(
{
  {
    type = "item",
    name = "chrome-ore",
    icon = "__angelssmelting__/graphics/icons/ore-chrome.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "processed-chrome",
    icon = "__angelssmelting__/graphics/icons/processed-chrome.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-chrome",
    icon = "__angelssmelting__/graphics/icons/pellet-chrome.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-chromate",
    icon = "__angelssmelting__/graphics/icons/solid-chromate.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-dichromate",
    icon = "__angelssmelting__/graphics/icons/solid-dichromate.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-chrome-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-chrome-oxide.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "ingot-chrome",
    icon = "__angelssmelting__/graphics/icons/ingot-chrome.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome",
    order = "g",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-molten-chrome",
    icon = "__angelssmelting__/graphics/icons/molten-chrome.png",
	icon_size = 32,
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 200/255, g = 186/255, b = 245/255},
    flow_color = {r = 200/255, g = 186/255, b = 245/255},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
	auto_barrel = false
  },
  {
    type = "item",
    name = "angels-plate-chrome",
    icon = "__angelssmelting__/graphics/icons/plate-chrome.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome-casting",
    order = "h",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-chrome",
    icon = "__angelssmelting__/graphics/icons/powder-chrome.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome-casting",
    order = "i",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-roll-chrome",
    icon = "__angelssmelting__/graphics/icons/roll-chrome.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-chrome-casting",
    order = "j",
    stack_size = 200
  },
}
)
